@@ -1,4 +1,4 @@
-#Copyright 2010-2011 Miquel Torres <tobami@googlemail.com>
+#Copyright 2010-2012 Miquel Torres <tobami@googlemail.com>
 #
 #Licensed under the Apache License, Version 2.0 (the "License");
 #you may not use this file except in compliance with the License.
@@ -69,22 +69,28 @@ def sync_node(node):
     It also injects the ipaddress to the node's config file if not already
     existent.
     """
+    # Get merged attributes
+    current_node = _build_node_data_bag()
     with lib.credentials():
-        # Get merged attributes
-        current_node = _build_node_data_bag()
         # Always configure Chef Solo
         solo.configure(current_node)
-        # Everything was configured alright, so save the node configuration
-        filepath = save_config(node, _get_ipaddress(node))
+        ipaddress = _get_ipaddress(node)
+    # Everything was configured alright, so save the node configuration
+    # This is done without credentials, so that we keep the node name used
+    # by the user and not the hostname or IP translated by .ssh/config
+    filepath = save_config(node, ipaddress)
+    with lib.credentials():
         try:
-            _synchronize_node(filepath)
+            # Synchronize the kitchen directory
+            _synchronize_node(filepath, node)
+            # Execute Chef Solo
             _configure_node()
         finally:
             _remove_local_node_data_bag()
             _node_cleanup()
 
 
-def _synchronize_node(configfile):
+def _synchronize_node(configfile, node):
     """Performs the Synchronize step of a Chef run:
     Uploads all cookbooks, all roles and all databags to a node and add the
     patch for data bags
@@ -96,8 +102,11 @@ def _synchronize_node(configfile):
     # First upload node.json
     remote_file = '/etc/chef/node.json'
     put(configfile, remote_file, use_sudo=True, mode=400)
+    root_user = "root"
+    if node.get('platform') in ["freebsd", "mac_os_x"]:
+        root_user = "wheel"
     with hide('stdout'):
-        sudo('chown root:root {0}'.format(remote_file))
+        sudo('chown root:{0} {1}'.format(root_user, remote_file))
     # Remove local temporary node file
     os.remove(configfile)
     # Synchronize kitchen
@@ -141,7 +150,8 @@ def update_dct(dic1, dic2):
 
 def _add_automatic_attributes(node):
     """Adds some of Chef's automatic attributes:
-        http://wiki.opscode.com/display/chef/Recipes#Recipes-CommonAutomaticAttributes
+        http://wiki.opscode.com/display/chef/Recipes#Recipes
+        -CommonAutomaticAttributes
 
     """
     node['fqdn'] = node['name']
@@ -153,7 +163,8 @@ def _add_merged_attributes(node, all_recipes, all_roles):
     """Merges attributes from cookbooks, node and roles
 
     Chef Attribute precedence:
-    http://wiki.opscode.com/display/chef/Attributes#Attributes-AttributeTypeandPrecedence
+    http://wiki.opscode.com/display/chef/Attributes#Attributes
+    -AttributeTypeandPrecedence
     LittleChef implements, in precedence order:
         - Cookbook default
         - Role default
@@ -226,8 +237,8 @@ def _build_node_data_bag():
         All attributes found in nodes/<item>.json file
         Default and override attributes from all roles
 
-    Returns the node object of the node which is about to be configured, or None
-    if this node object cannot be found.
+    Returns the node object of the node which is about to be configured, or
+    None if this node object cannot be found.
 
     """
     current_node = None
@@ -292,12 +303,13 @@ def _node_cleanup():
 
 
 def _add_search_patch():
-    """ Adds chef_solo_search_lib cookbook, which provides a library to read and search
-    data bags.
+    """ Adds chef_solo_search_lib cookbook, which provides a library to read
+    and search data bags
+
     """
     # Create extra cookbook dir
     lib_path = os.path.join(
-                node_work_path, cookbook_paths[0], 'chef_solo_search_lib', 'libraries')
+        node_work_path, cookbook_paths[0], 'chef_solo_search_lib', 'libraries')
     with hide('running', 'stdout'):
         sudo('mkdir -p {0}'.format(lib_path))
     # Add search and environment patch to the node's cookbooks
