@@ -1,4 +1,4 @@
-#Copyright 2010-2011 Miquel Torres <tobami@googlemail.com>
+#Copyright 2010-2012 Miquel Torres <tobami@googlemail.com>
 #
 #Licensed under the Apache License, Version 2.0 (the "License");
 #you may not use this file except in compliance with the License.
@@ -118,15 +118,20 @@ def node(*nodes):
     if not(littlechef.__cooking__ and
             'node:' not in sys.argv[-1] and
             'nodes_with_role:' not in sys.argv[-1]):
-        # If user didn't type recipe:X, role:Y or deploy_chef, just run configure
+        # If user didn't type recipe:X, role:Y or deploy_chef,
+        # configure the nodes
         for hostname in env.hosts:
             env.host = hostname
             env.host_string = hostname
-            lib.print_header("Configuring {0}".format(env.host))
-            # Read node data and configure node
             node = lib.get_node(env.host)
-            if not __testing__:
-                chef.sync_node(node)
+            if node.get('dummy'):
+                lib.print_header("Skipping dummy: {0}".format(env.host))
+            else:
+                lib.print_header("Configuring {0}".format(env.host))
+                if __testing__:
+                    print "TEST: would now configure {0}".format(env.host)
+                else:
+                    chef.sync_node(node)
 
 
 def deploy_chef(gems="no", ask="yes", version="0.10",
@@ -369,7 +374,7 @@ def _readconfig():
         pass
 
     if user_specified and not env.password and not env.ssh_config:
-        abort('You need to define a password or a ssh-config file in auth.cfg.')
+        abort('You need to define a password or a ssh-config file in auth.cfg')
 
 
 # Only read config if fix is being used and we are not creating a new kitchen
